

-- LilSparky's Workshop -- Addon for Slarti's Advanced Tradeskill Window mod for WOW
-- Lilsparky of Lothar
-- v0.3
-- oct.11.2007


LSW_VERSION = "LSW v0.3";


ATSW_ShowWindow_ORIGINAL = nil;

SkilletFrame_Show_ORIGINAL = nil;
SkilletFrame_Update_ORIGINAL = nil;

TradeSkillFrame_Show_ORIGINAL = nil;
TradeSkillFrame_Update_ORIGINAL = nil;
---

LSW_initialized = false;

LSW_Mode = "TradeSkill";

LSW_AuctioneerHook = "auctioneer";

LSW_TRADESKILL_INDEX_MAX = 8
LSW_CRAFT_INDEX_MAX = 8

LSW_MINIMUM_REAGENT_AUCTIONS = 10
LSW_MINIMUM_ITEM_AUCTIONS = 1

LSW_itemFateColor={};
LSW_itemFateColor["d"]="ff008000";
LSW_itemFateColor["a"]="ff809060";
LSW_itemFateColor["v"]="ff206080";
LSW_itemFateColor["?"]="ff800000";

LSW_globalSync = 1;
LSW_skillPriceCache={};

LSW_globalFate = 0;
LSW_globalFateMax = 3;

-- these could certainly be made language specific if needed
LSW_itemFateList={};
LSW_itemFateList[1]="a";		-- auction
LSW_itemFateList[2]="v";		-- vendor
LSW_itemFateList[3]="d";		-- disenchant


LSW_skillWidthNarrow = 223;
LSW_skillWidthWide = 243;

LSW_skillWidth = LSW_skillWidthWide;


function LSW_formatMoney(moneyString,dark)
	local money = tonumber(moneyString);
	local TEXT_NONE = "-- --"

	local GSC_GOLD="ffffd100"
	local GSC_SILVER="ffe6e6e6"
	local GSC_COPPER="ffc8602c"
	
	if (dark==1) then
		GSC_GOLD = "ff807000"
		GSC_SILVER = "ff808080"
		GSC_COPPER = "ff643016"
	end
	
	local g, s, c;
	local digits = 0
	
	g = math.floor(money/10000);
	s = math.fmod(math.floor(money/100),100);
	c = math.fmod(money,100);

	if (money > 0) then
		digits = math.floor(math.log10(money)+1)
	end
	
	if ( digits < 3 ) then
		gsc = string.format("   |c%s%2d|r",  GSC_COPPER, c);
	elseif ( digits < 5 ) then
		gsc = string.format("|c%s%2d|r |c%s%02d|r", GSC_SILVER, s, GSC_COPPER, c)
	elseif ( digits < 7 ) then
		gsc = string.format("|c%s%2d|r |c%s%02d|r", GSC_GOLD, g, GSC_SILVER, s)
	else
		gsc = string.format("|c%s%5d|r", GSC_GOLD, g);
	end

	return gsc
end


function LSW_GetTradeSkillInfo(index)
	local skillName, skillType, numAvailable, isExpanded;
	
	if (LSW_Mode == "ATSW") then
		skillName, craftSubSpellName, skillType, numAvailable, isExpanded = ATSW_GetTradeSkillInfo(index);
	elseif (LSW_Mode == "Craft" or (LSW_Mode == "Skillet" and Skillet:IsCraft())) then
		skillName, craftSubSpellName, skillType, numAvailable, isExpanded = GetCraftInfo(index);
	else
		skillName, skillType, numAvailable, isExpanded = GetTradeSkillInfo(index);
	end
	
	return skillName, skillType, numAvailable, isExpanded;
end


function LSW_GetTradeSkillNumMade(index)
	if (LSW_Mode == "ATSW") then
		return ATSW_GetTradeSkillNumMade(index);
	elseif (LSW_Mode == "Craft" or (LSW_Mode == "Skillet" and Skillet:IsCraft())) then
		return 1, 1
	else
		return GetTradeSkillNumMade(index);
	end	
end

function LSW_GetTradeSkillNumReagents(index)
	
	if (LSW_Mode == "ATSW") then
		return ATSW_GetTradeSkillNumReagents(index);
	elseif (LSW_Mode == "Craft" or (LSW_Mode == "Skillet" and Skillet:IsCraft())) then
		return GetCraftNumReagents(index);
	else
		return GetTradeSkillNumReagents(index);
	end
end

function LSW_GetTradeSkillReagentInfo(index, reagentIndex)

	if (LSW_Mode == "ATSW") then
		return ATSW_GetTradeSkillReagentInfo(index, reagentIndex);
	elseif (LSW_Mode == "Craft" or (LSW_Mode == "Skillet" and Skillet:IsCraft())) then
		return GetCraftReagentInfo(index, reagentIndex);
	else
		return GetTradeSkillReagentInfo(index, reagentIndex);
	end
end

function LSW_GetTradeSkillReagentItemLink(index, reagentIndex)
	
	if (LSW_Mode == "ATSW") then
		return ATSW_GetTradeSkillReagentItemLink(index, reagentIndex);
	elseif (LSW_Mode == "Craft" or (LSW_Mode == "Skillet" and Skillet:IsCraft())) then
		return GetCraftReagentItemLink(index, reagentIndex);
	else
		return GetTradeSkillReagentItemLink(index, reagentIndex);
	end	
end

function LSW_GetTradeSkillItemLink(index)
	
	if (LSW_Mode == "ATSW") then
		return ATSW_GetTradeSkillItemLink(index)
	elseif (LSW_Mode == "Craft" or (LSW_Mode == "Skillet" and Skillet:IsCraft())) then
		return GetCraftItemLink(index);
	else
		return GetTradeSkillItemLink(index);
	end	
end



function LSW_findItemID(link)
	if ( type(link) ~= 'string' ) then return end
	local i,j,itemID = string.find(link, "|Hitem:(%d+):");	
-- DEFAULT_CHAT_FRAME:AddMessage("itemID - "..itemID);	
	return tonumber(itemID); 
end


function LSW_itemPriceVendor(link)
	local sell = 0
	local buy = 0
	local itemInfo = nil;
	
	local itemID = LSW_findItemID(link)
	
	if (itemID and itemID > 0) and (Informant) then
		itemInfo = Informant.GetItem(itemID)
	end
	if (not itemInfo) then return 0,0, true end

	buy = tonumber(itemInfo.buy) or 0
	sell = tonumber(itemInfo.sell) or 0

	return buy, sell, false
end



function LSW_itemPriceAuctioneer(link, minSeen) -- auctioneer version
	if (not Auctioneer or not link) then return 0, true; end

	if (not minSeen) then minSeen = 1 end;
	
-- DEFAULT_CHAT_FRAME:AddMessage(link);

	local itemKey = Auctioneer.ItemDB.CreateItemKeyFromLink(link);
	local dataMissing = false;
	
	local itemTotals = Auctioneer.HistoryDB.GetItemTotals(itemKey, auctKey);

	local sellPrice=0;
	
	if (not itemTotals) then
		return 0,0,true;
	end

-- DEFAULT_CHAT_FRAME:AddMessage(itemTotals.seenCount.." seen");
	if (itemTotals.seenCount < minSeen) then
		return 0, true;
	else		
--		sellPrice  = Auctioneer.Statistic.GetMarketPrice(itemKey, auctKey);
		
		sellPrice  = Auctioneer.Statistic.GetHSP(itemKey, auctKey,1);
		dataMissing = false;		
	end
	
	return sellPrice, dataMissing;
end


function LSW_itemPriceAucAdvanced(link, minSeen) -- aucadvanced version (work in progress)
	local numSeen;
	
	if (not link) then return 0, true; end
	
	if (not minSeen) then minSeen = 1; end

	local sellPrice=0;
	sellPrice, numSeen = AucAdvanced.API.GetMarketValue(link, AucAdvanced.GetFaction());
				
	if (not sellPrice or numSeen < minSeen) then
		return 0, true;
	end

	return sellPrice, flse;
end


function LSW_itemPriceAuctioneerBoth(link, minSeen) -- use both aucadvanced and auctioneer data
	if (not Auctioneer or not AucAdvanced or not link) then return 0, true; end

	if (not minSeen) then minSeen = 1 end;
	
-- DEFAULT_CHAT_FRAME:AddMessage(link);

	local itemKey = Auctioneer.ItemDB.CreateItemKeyFromLink(link);
	local dataMissing = false;
	
	local itemTotals = Auctioneer.HistoryDB.GetItemTotals(itemKey, auctKey);
	local sellPrice=0;
	local numSeen=0;
	
	if (itemTotals) then
		numSeen = itemTotals.seenCount;
		
		sellPrice  = Auctioneer.Statistic.GetHSP(itemKey, auctKey,1);
--		dummy, sellPrice  = Auctioneer.Statistic.GetMarketPrice(itemKey, auctKey);

	end

	local sellPriceAdv, numSeenAdv = AucAdvanced.API.GetMarketValue(link, AucAdvanced.GetFaction());
	
	if (sellPriceAdv) then
		sellPrice = (sellPrice * numSeen + sellPriceAdv * numSeenAdv) / (numSeenAdv + numSeen);
		numSeen = numSeenAdv + numSeen;
	end
	
	if (numSeen < minSeen) then
		return 0, true;
	end
	
	return sellPrice, false;
end



function LSW_itemValuation(skillName, skillLink, skillID)

	if (LSW_skillPriceCache[skillName] == nil) then
		LSW_skillPriceCache[skillName]={}
		LSW_skillPriceCache[skillName].sync = 0
		LSW_skillPriceCache[skillName].valueAmount = {};
	else
		if (LSW_skillPriceCache[skillName].sync == LSW_globalSync) then
			if (LSW_globalFate==0) then
				return LSW_skillPriceCache[skillName].costAmount, LSW_skillPriceCache[skillName].valueAmount[LSW_globalFate], LSW_skillPriceCache[skillName].itemFate;
			else
				return LSW_skillPriceCache[skillName].costAmount, LSW_skillPriceCache[skillName].valueAmount[LSW_globalFate], LSW_itemFateList[LSW_globalFate];
			end
		end
	end
	
	local cache = LSW_skillPriceCache[skillName];
	cache.synce = LSW_globalSync;
	cache.valueAmount[1] = 0;
	cache.valueAmount[2] = 0;
	cache.valueAmount[3] = 0;
	
	local sell = 0;
	local buy = 0;
	local stacks = 1;
	local itemFate = "?"
	
	local dummy;
	
	local numReagents;
	
	numReagents = LSW_GetTradeSkillNumReagents(skillID);
	
	for i=1, numReagents, 1 do
		local reagentName, dummy, reagentCount = LSW_GetTradeSkillReagentInfo(skillID, i);
		local reagentLink = LSW_GetTradeSkillReagentItemLink(skillID, i);
		
		local sellAtAuction;
		local buyFromVendor;
		local ahDataMissing;
		
		local reagentValue;
		
		sellAtAuction, ahDataMissing = LSW_itemPrice(reagentLink, LSW_MININUM_REAGENT_AUCTIONS);
		buyFromVendor = LSW_itemPriceVendor(reagentLink);

-- calculate the cost of reagents.  if ah data exists, use it.  if no ah data exists then use the buy from vendor price

		if (ahDataMissing) then
			reagentValue = buyFromVendor;
		else
			reagentValue = sellAtAuction;
		end

--DEFAULT_CHAT_FRAME:AddMessage(reagentLink.."  "..reagentValue);
	

		buy = buy + reagentValue * reagentCount;
	end
		
	cache.costAmount = buy;  -- costAmount = how much it would cost to purchase the reagents
	
	if (skillLink and GetItemInfo(skillLink)) then  -- items return info, enchants return nil
		local min,max;
		
		min, max = LSW_GetTradeSkillNumMade(skillID);
		
-- DEFAULT_CHAT_FRAME:AddMessage(skillName.."  "..min.." "..max);

		stacks = (min+max)/2;
	
		sell = LSW_itemPrice(skillLink, LSW_MINIUMUM_ITEM_AUCTIONS);
		cache.valueAmount[1] = sell * stacks;  -- valueAmount[1] = how much an item might auction for
	
		dummy, sell = LSW_itemPriceVendor(skillLink);
		cache.valueAmount[2] = sell * stacks;  -- valueAmount[2] = how much an item would sell to a vendor for
	
		if (LSW_AuctioneerHook == "auctioneer") then
			if (Enchantrix) then
				sell = Enchantrix.Storage.GetItemDisenchantTotals(skillLink); -- auctioneer
			else
				sell = 0;
			end
		else
			if (Enchantrix) then
				dummy, dummy, dummy, sell = Enchantrix.Storage.GetItemDisenchantTotals(skillLink); -- aucadvanced
			else
				sell = 0
			end
		end
	end
	
	if (sell) then
		cache.valueAmount[3] = sell * stacks;  -- valueAmount[3] = how much an item would sell for if de'd
	end
	
	
	if (cache.valueAmount[1] >= cache.valueAmount[2] and cache.valueAmount[1] >= cache.valueAmount[3]) then
		cache.valueAmount[0] = cache.valueAmount[1];
		cache.itemFate = LSW_itemFateList[1];
	else
		if (cache.valueAmount[2] >= cache.valueAmount[3] and cache.valueAmount[2] >= cache.valueAmount[1]) then
			cache.valueAmount[0] = cache.valueAmount[2];
			cache.itemFate = LSW_itemFateList[2];
		else
			cache.valueAmount[0] = cache.valueAmount[3];
			cache.itemFate = LSW_itemFateList[3];
		end
	end
	
	LSW_skillPriceCache[skillName].sync = LSW_globalSync;
				
	if (LSW_globalFate==0) then
		return LSW_skillPriceCache[skillName].costAmount, LSW_skillPriceCache[skillName].valueAmount[LSW_globalFate], LSW_skillPriceCache[skillName].itemFate;
	else
		return LSW_skillPriceCache[skillName].costAmount, LSW_skillPriceCache[skillName].valueAmount[LSW_globalFate], LSW_itemFateList[LSW_globalFate];
	end
end



function LSW_SkillShow()
	if (LSW_Mode == "Craft") then
		if (GetCraftName() ~= "Enchanting") then
			return;
		end
	end
	
	
	this:SetWidth(LSW_skillWidth);
	
	local name = this:GetName();
	local itemLevel = "?";
	local x;
	local id;
	
	local buttonLevel;
	local buttonCost;
	local buttonValue;
	
	if (LSW_Mode == "Skillet") then
		id = string.sub(name,20); -- SkilletScrollButton[id]
		
		buttonValue = getglobal("LSWTradeSkillValue"..id);
		buttonCost = getglobal("LSWTradeSkillCost"..id);
		buttonLevel = getglobal("LSWTradeSkillItemLevel"..id);
	elseif (LSW_Mode == "ATSW") then
		id = string.sub(name,10); -- ATSWSkill[id]
		
		buttonValue = getglobal("LSWTradeSkillValue"..id);
		buttonCost = getglobal("LSWTradeSkillCost"..id);
		buttonLevel = getglobal("LSWTradeSkillItemLevel"..id);
	elseif (LSW_Mode == "Craft") then
		id = string.sub(name,6); -- Craft[id]
		
		buttonLevel = getglobal("LSWCraftItemLevel"..id);
		buttonCost = getglobal("LSWCraftCost"..id);
		buttonValue = getglobal("LSWCraftValue"..id);
	else
		id = string.sub(name,16); -- TradeSkillSkill[id]
		
		buttonValue = getglobal("LSWTradeSkillValue"..id);
		buttonCost = getglobal("LSWTradeSkillCost"..id);
		buttonLevel = getglobal("LSWTradeSkillItemLevel"..id);
	end
	
	if (not buttonValue) then return; end
	
	
	local skillName;
	local skillLink;
	local skillType;
	local skillID;
	
	if (LSW_Mode == "ATSW") then
		local tradeSkillID=this:GetID();
		local listpos=ATSW_GetSkillListingPos(tradeSkillID);
	
		if(atsw_skilllisting[listpos]) then
			skillName = atsw_skilllisting[listpos].name;
			skillLink = atsw_skilllisting[listpos].link;
			skillType = atsw_skilllisting[listpos].type;
			skillID =   atsw_skilllisting[listpos].id;
		end
		
--		DEFAULT_CHAT_FRAME:AddMessage("ATSW: "..skillName.." "..skillLink.." "..skillType.." "..skillID);

	else
		skillID=this:GetID();
		skillName, skillType = LSW_GetTradeSkillInfo(skillID);
		skillLink = LSW_GetTradeSkillItemLink(skillID);
	end
	
	
	if (skillName and skillType ~= "header") then						
		local costAmount, valueAmount, itemFate = LSW_itemValuation(skillName, skillLink, skillID);
						
		local itemFateString = string.format("|c%s%s|r", LSW_itemFateColor[itemFate], itemFate);
						
		if (costAmount < valueAmount) then
			buttonValue:SetText(LSW_formatMoney(valueAmount,0)..itemFateString);
			buttonCost:SetText(LSW_formatMoney(costAmount,1).."  ");
		else
			buttonValue:SetText(LSW_formatMoney(valueAmount,1)..itemFateString);
			buttonCost:SetText(LSW_formatMoney(costAmount,1).."  ");
		end
					
		if (skillLink and skillName and skillName ~= "") then		
			x, x, x, x, itemLevel = GetItemInfo(skillLink);
		
			if (itemLevel) and (itemLevel <= UnitLevel("player")) then
				buttonLevel:SetTextColor(.8,.8,.8);
			else
				buttonLevel:SetTextColor(1,.2,.2);
			end
		end
			
		if (itemLevel == 0) then
			itemLevel = "1"
		end
		
		if (itemLevel) then
			buttonLevel:SetText(itemLevel);
			buttonLevel:Show();
			buttonValue:Show();
		else
			buttonLevel:SetText("");
			buttonLevel:Hide();
		end
		
		buttonCost:Show();
	end
end


function LSW_SkillHide()
	local name = this:GetName();
	local id;
	
	local buttonLevel;
	local buttonCost;
	local buttonValue;
	

	if (LSW_Mode == "Skillet") then
		id = string.sub(name,20); -- SkilletScrollButton[id]
		
		buttonValue = getglobal("LSWTradeSkillValue"..id);
		buttonCost = getglobal("LSWTradeSkillCost"..id);
		buttonLevel = getglobal("LSWTradeSkillItemLevel"..id);
	elseif (LSW_Mode == "ATSW") then
		id = string.sub(name,10); -- ATSWSkill[id]
		
		buttonValue = getglobal("LSWTradeSkillValue"..id);
		buttonCost = getglobal("LSWTradeSkillCost"..id);
		buttonLevel = getglobal("LSWTradeSkillItemLevel"..id);
	elseif (LSW_Mode == "Craft") then
		id = string.sub(name,6); -- Craft[id]
		
		buttonLevel = getglobal("LSWCraftItemLevel"..id);
		buttonCost = getglobal("LSWCraftCost"..id);
		buttonValue = getglobal("LSWCraftValue"..id);
	else
		id = string.sub(name,16); -- TradeSkillSkill[id]
		
		buttonValue = getglobal("LSWTradeSkillValue"..id);
		buttonCost = getglobal("LSWTradeSkillCost"..id);
		buttonLevel = getglobal("LSWTradeSkillItemLevel"..id);
	end
	
	if (buttonCost) then buttonCost:Hide(); end
	if (buttonValue) then buttonValue:Hide(); end
	if (buttonLevel) then buttonLevel:Hide(); end
end


function LSW_ItemLevelButton_OnEnter()
	GameTooltip:SetOwner(this, "ANCHOR_NONE");
	GameTooltip:SetPoint("BOTTOMRIGHT", "UIParent", "BOTTOMRIGHT", -CONTAINER_OFFSET_X - 13, CONTAINER_OFFSET_Y);
	GameTooltip:SetText("Required level to use crafted item.");
	GameTooltip:Show();
end

function LSW_ItemLevelButton_OnLeave()
	GameTooltip:Hide();
end



function LSW_CostButton_OnEnter()
-- DEFAULT_CHAT_FRAME:AddMessage("skill cost enter");
   	GameTooltip:SetOwner(this, "ANCHOR_NONE");
	GameTooltip:SetPoint("BOTTOMRIGHT", "UIParent", "BOTTOMRIGHT", -CONTAINER_OFFSET_X - 13, CONTAINER_OFFSET_Y);
	GameTooltip:SetText("Estimated cost to use skill.");
	GameTooltip:Show();
end

function LSW_CostButton_OnLeave()
	GameTooltip:Hide();
end


-- click on the value and toggle the BEST/AUCTION/VENDOR/DE price consideration

function LSW_ValueButton_OnClick(button)
	if(button=="LeftButton") then
		LSW_globalFate = LSW_globalFate + 1;
		
		if (LSW_globalFate > LSW_globalFateMax) then
			LSW_globalFate = 0;
		end
		
		LSW_ValueButton_OnEnter()
		
		if (LSW_Mode == "Skillet") then
			LSW_UpdateWindowSkillet();
		elseif (LSW_Mode == "ATSW") then
			ATSWFrame_Update();
		elseif (LSW_Mode == "Craft") then
			LSW_UpdateWindowCraft();
		else
			LSW_UpdateWindowStandard();
		end
	end
end

function LSW_ValueButton_OnEnter()
	GameTooltip:SetOwner(this, "ANCHOR_NONE");
	GameTooltip:SetPoint("BOTTOMRIGHT", "UIParent", "BOTTOMRIGHT", -CONTAINER_OFFSET_X - 13, CONTAINER_OFFSET_Y);
	
	if (LSW_globalFate == 0) then
		GameTooltip:SetText("Estimated value of crafted item(s).");
		GameTooltip:AddLine("Best price shown.");
		GameTooltip:AddLine("a = auction  v = vendor  d = disenchant");
	elseif (LSW_globalFate == 1) then
		GameTooltip:SetText("Estimated auction value of crafted item(s).");
	elseif (LSW_globalFate == 2) then
		GameTooltip:SetText("Vendor purchase price of crafted item(s).");
	else
		GameTooltip:SetText("Estimated disenchant value of crafted item(s).");
	end
	
	GameTooltip:Show();
end

function LSW_ValueButton_OnLeave()
	GameTooltip:Hide();
end


function LSW_ShowWindowATSW()
	LSW_globalSync = LSW_globalSync + 1;
	LSW_Mode = "ATSW";
	
	ATSW_ShowWindow_ORIGINAL();
	
	local scrollFrame = ATSWListScrollFrame;
	
	if (ATSWListScrollFrame:IsVisible()) then
		LSW_skillWidth = LSW_skillWidthNarrow;
	else
		LSW_skillWidth = LSW_skillWidthWide;
	end
		
	local ATSW_title = ATSWFrameTitleText:GetText();
	ATSWFrameTitleText:SetText(ATSW_title.." (w/ "..LSW_VERSION..")");
	ATSWFrame_Update();
end



function LSW_ShowWindowSkillet()
	LSW_globalSync = LSW_globalSync + 1;
	LSW_Mode = "Skillet";
	
	Skillet_ShowWindow_ORIGINAL(Skillet);
	
	if (SkilletSkillList:IsVisible()) then
		LSW_skillWidth = LSW_skillWidthNarrow;
	else
		LSW_skillWidth = LSW_skillWidthWide;
	end
		
--	local ATSW_title = ATSWFrameTitleText:GetText();
--	ATSWFrameTitleText:SetText(ATSW_title.." (w/ "..LSW_VERSION..")");
--	ATSWFrame_Update();
end


function LSW_UpdateWindowSkillet()
	LSW_Mode = "Skillet";

	for i=1, LSW_TRADESKILL_INDEX_MAX, 1 do
		local tradeSkillButton = getglobal("SkilletScrollButton"..i);
		tradeSkillButton:Hide();
	end

	SkilletFrame_Update_ORIGINAL(Skillet);
	
	local title = getglobal("SkilletTitleText");
    if (title) then
    	title:SetText("Skillet Trade Skills"..": "..Skillet.currentTrade.." ("..LSW_VERSION..")")
    end

--	local name = GetTradeSkillLine()
--	TradeSkillFrameTitleText:SetText(name.." ("..LSW_VERSION..")");
end


function LSW_ShowWindowStandard()
	LSW_globalSync = LSW_globalSync + 1;
	LSW_Mode = "TradeSkill";
		
	TradeSkillFrame_Show_ORIGINAL();

	if (TradeSkillListScrollFrame:IsVisible()) then
		LSW_skillWidth = LSW_skillWidthNarrow;
	else
		LSW_skillWidth = LSW_skillWidthWide;
	end
	
	TradeSkillFrame_Update();	
end


function LSW_UpdateWindowStandard()
	LSW_Mode = "TradeSkill";

	for i=1, LSW_TRADESKILL_INDEX_MAX, 1 do
		local tradeSkillButton = getglobal("TradeSkillSkill"..i);
		tradeSkillButton:Hide();
	end
	TradeSkillFrame_Update_ORIGINAL()
	local name = GetTradeSkillLine()
	TradeSkillFrameTitleText:SetText(name.." ("..LSW_VERSION..")");
end


function LSW_ShowWindowCraft()
	if (GetCraftName() ~= "Enchanting") then
		for i=1, LSW_CRAFT_INDEX_MAX, 1 do
			local craftButton = getglobal("Craft"..i);
			craftButton:SetTextFontObject("GameFontNormal");
			craftButton:SetHighlightFontObject("GameFontHighlight");
			craftButton:SetDisabledFontObject("GameFontDisable");
		end
		
		CraftFrame_Show_ORIGINAL();
--		CraftFrame_Update();
		return;
	else
		for i=1, LSW_CRAFT_INDEX_MAX, 1 do
			local craftButton = getglobal("Craft"..i);
			craftButton:SetTextFontObject("GameFontNormalSmall");
			craftButton:SetHighlightFontObject("GameFontHighlightSmall");
			craftButton:SetDisabledFontObject("GameFontDisableSmall");
		end

	end

	LSW_globalSync = LSW_globalSync + 1;
	LSW_Mode = "Craft";
	
	CraftFrame_Show_ORIGINAL();

	if (CraftListScrollFrame:IsVisible()) then
		LSW_skillWidth = LSW_skillWidthNarrow;
	else
		LSW_skillWidth = LSW_skillWidthWide;
	end
	CraftFrame_Update();
end

function LSW_UpdateWindowCraft()
	if (GetCraftName() ~= "Enchanting") then
		CraftFrame_Update_ORIGINAL();
		return;
	end
	
	LSW_Mode = "Craft";

	for i=1, LSW_CRAFT_INDEX_MAX, 1 do
		local craftButton = getglobal("Craft"..i);
		craftButton:Hide();
	end
	CraftFrame_Update_ORIGINAL()
	CraftFrameTitleText:SetText(GetCraftName().." ("..LSW_VERSION..")");
end


function LSW_ButtonInitSkillet(i)
	local skillButton = getglobal("SkilletScrollButton"..i);
	skillButton:SetScript("OnShow", LSW_SkillShow);
	skillButton:SetScript("OnHide", LSW_SkillHide);	
	skillButton:SetTextFontObject("GameFontNormalSmall");
	skillButton:SetHighlightFontObject("GameFontHighlightSmall");
	skillButton:SetDisabledFontObject("GameFontDisableSmall");
	
	
	local buttonValue = getglobal("LSWTradeSkillValue"..i);
	buttonValue:SetParent("SkilletFrame");
	buttonValue:SetPoint("TOPLEFT","SkilletScrollButton"..i,"TOPRIGHT",5,0);
	buttonValue:SetText("00 00");
	buttonValue:SetWidth(30);
	buttonValue:Hide();
	
	
	local buttonCost = getglobal("LSWTradeSkillCost"..i);
	buttonCost:SetParent("SkilletFrame");
	buttonCost:SetPoint("TOPLEFT","LSWTradeSkillValue"..i,"TOPRIGHT",15,0);
	buttonCost:SetText("00 00");
	buttonCost:SetWidth(30);
	buttonCost:Hide();
	

	local buttonLevel = getglobal("LSWTradeSkillItemLevel"..i);
	buttonLevel:SetParent("SkilletFrame");
	buttonLevel:SetPoint("TOPLEFT","SkilletScrollButton"..i,"TOPLEFT",0,0);
	buttonLevel:SetText("");
	buttonLevel:Hide();
end


function LSW_ButtonInitATSW(i)
	local atswButton = getglobal("ATSWSkill"..i);
	atswButton:SetScript("OnShow", LSW_SkillShow);
	atswButton:SetScript("OnHide", LSW_SkillHide);	
	atswButton:SetTextFontObject("GameFontNormalSmall");
	atswButton:SetHighlightFontObject("GameFontHighlightSmall");
	atswButton:SetDisabledFontObject("GameFontDisableSmall");
	
	
	local buttonValue = getglobal("LSWTradeSkillValue"..i);
	buttonValue:SetParent("ATSWFrame");
	buttonValue:SetPoint("TOPLEFT","ATSWSkill"..i,"TOPRIGHT",5,0);
	buttonValue:SetText("00 00");
	buttonValue:SetWidth(30);
	buttonValue:Hide();
	
	
	local buttonCost = getglobal("LSWTradeSkillCost"..i);
	buttonCost:SetParent("ATSWFrame");
	buttonCost:SetPoint("TOPLEFT","LSWTradeSkillValue"..i,"TOPRIGHT",15,0);
	buttonCost:SetText("00 00");
	buttonCost:SetWidth(30);
	buttonCost:Hide();
	

	local buttonLevel = getglobal("LSWTradeSkillItemLevel"..i);
	buttonLevel:SetParent("ATSWFrame");
	buttonLevel:SetPoint("TOPLEFT","ATSWSkill"..i,"TOPLEFT",0,0);
	buttonLevel:SetText("");
	buttonLevel:Hide();
end


function LSW_ButtonInitStandard(i)
	local tradeSkillButton = getglobal("TradeSkillSkill"..i);
	tradeSkillButton:SetScript("OnShow", LSW_SkillShow);
	tradeSkillButton:SetScript("OnHide", LSW_SkillHide);	
	tradeSkillButton:SetTextFontObject("GameFontNormalSmall");
	tradeSkillButton:SetHighlightFontObject("GameFontHighlightSmall");
	tradeSkillButton:SetDisabledFontObject("GameFontDisableSmall");
	tradeSkillButton:SetWidth(LSW_skillWidth);
	
	local buttonValue = getglobal("LSWTradeSkillValue"..i);
	buttonValue:SetParent("TradeSkillFrame");
	buttonValue:SetPoint("TOPLEFT","TradeSkillSkill"..i,"TOPRIGHT",5,0);
	buttonValue:SetText("00 00");
	buttonValue:SetWidth(30);
	buttonValue:Hide();
	
	
	local buttonCost = getglobal("LSWTradeSkillCost"..i);
	buttonCost:SetParent("TradeSkillFrame");
	buttonCost:SetPoint("TOPLEFT","LSWTradeSkillValue"..i,"TOPRIGHT",15,0);
	buttonCost:SetText("00 00");
	buttonCost:SetWidth(30);
	buttonCost:Hide();
	

	local buttonLevel = getglobal("LSWTradeSkillItemLevel"..i);
	buttonLevel:SetParent("TradeSkillFrame");
	buttonLevel:SetPoint("TOPLEFT","TradeSkillSkill"..i,"TOPLEFT",0,0);
	buttonLevel:SetText("");
	
	
	
	local craftButton = getglobal("Craft"..i);
	craftButton:SetScript("OnShow", LSW_SkillShow);
	craftButton:SetScript("OnHide", LSW_SkillHide);	
	craftButton:SetTextFontObject("GameFontNormalSmall");
	craftButton:SetHighlightFontObject("GameFontHighlightSmall");
	craftButton:SetDisabledFontObject("GameFontDisableSmall");
	craftButton:SetWidth(LSW_skillWidth);
	
	local buttonValue = getglobal("LSWCraftValue"..i);
	buttonValue:SetParent("CraftFrame");
	buttonValue:SetPoint("TOPLEFT","Craft"..i,"TOPRIGHT",5,0);
	buttonValue:SetText("00 00");
	buttonValue:SetWidth(30);
	buttonValue:Hide();
	
	
	local buttonCost = getglobal("LSWCraftCost"..i);
	buttonCost:SetParent("CraftFrame");
	buttonCost:SetPoint("TOPLEFT","LSWCraftValue"..i,"TOPRIGHT",15,0);
	buttonCost:SetText("00 00");
	buttonCost:SetWidth(30);
	buttonCost:Hide();
	
	local buttonLevel = getglobal("LSWCraftItemLevel"..i);
	buttonLevel:SetParent("CraftFrame");
	buttonLevel:SetPoint("TOPLEFT","Craft"..i,"TOPLEFT",0,0);
	buttonLevel:SetText("");

end


function LSW_OnLoad()
	LSW_Initialize();
	LSW_initialized = true;
end


--- 
function LSW_OnLoad_DISABLED()	
	
	if (IsAddOnLoaded("AdvancedTradeSkillWindow")) then
		LSW_Initialize();
		LSW_initialized = true;
	end
	
	this:RegisterEvent("TRADE_SKILL_SHOW");
	this:RegisterEvent("TRADE_SKILL_UPDATE");
end


function LSW_OnEvent(event)
	if (LSW_initialized == false) then
		if (event == "CRAFT_SHOW" or event == "TRADE_SKILL_SHOW") then
			LSW_Initialize();
			LSW_initialized = true;
		end
	end
end


function LSW_Initialize()
	DEFAULT_CHAT_FRAME:AddMessage("LilSparky's Workshop v0.2");
	LoadAddOn("Auctioneer");  -- demands Auctioneer load (too hacky?)
	
	if (not Auctioneer) and (not AucAdvanced) then
		DEFAULT_CHAT_FRAME:AddMessage("ERROR: LilSparky's Workshop requires either Auctioneer or AucAdvanced to function properly.");
		return;
	end
	
	if (AucAdvanced and AucAdvanced.Version) then
		LSW_AuctioneerHook = "aucadv"
		
		if (Auctioneer and Auctioneer.Version) then
			DEFAULT_CHAT_FRAME:AddMessage("LilSparky's Workshop has found Auctioneer (v"..Auctioneer.Version..") and AucAdvanced (v"..AucAdvanced.Version..")");		
			LSW_itemPrice = LSW_itemPriceAuctioneerBoth
		else
			DEFAULT_CHAT_FRAME:AddMessage("LilSparky's Workshop has found AucAdvanced (v"..AucAdvanced.Version..")");		
			LSW_itemPrice = LSW_itemPriceAucAdvanced
		end
	else
		DEFAULT_CHAT_FRAME:AddMessage("LilSparky's Workshop has found Auctioneer (v"..Auctioneer.Version..")");		

		LSW_AuctioneerHook = "auctioneer"
		LSW_itemPrice = LSW_itemPriceAuctioneer
	end

	
	if (Enchantrix) then
		LSW_globalFateMax = 3
	else
		DEFAULT_CHAT_FRAME:AddMessage("WARNING: LilSparky's Workshop needs Enchantrix to calculate disenchant values.");
		DEFAULT_CHAT_FRAME:AddMessage("Addon will still work, but no disenchant values will be calculated.");
		LSW_globalFateMax = 2
	end
	
	
	if (Skillet and Skillet.version) then
		LSW_Mode = "Skillet"
		
		DEFAULT_CHAT_FRAME:AddMessage("LilSparky's Workshop plugging into Skillet (v"..Skillet.version..")");


		SkilletFrame_Show_ORIGINAL = Skillet.ShowTradeSkillsWindow;
		Skillet.ShowTradeSkillsWindow = LSW_ShowWindowSkillet;
				
		SkilletFrame_Update_ORIGINAL = Skillet.UpdateTradeSkillsWindow;
		Skillet.UpdateTradeSkillsWindow = LSW_UpdateWindowSkillet;
		
		
		LSW_TRADESKILL_INDEX_MAX = SKILLET_TRADE_SKILLS_DISPLAYED;
		
		LSW_skillWidthNarrow = 213;
		LSW_skillWidthWide = 233;
		
		LSW_skillWidth = LSW_skillWidthNarrow;

		for i=1, LSW_TRADESKILL_INDEX_MAX, 1 do
			LSW_ButtonInitSkillet(i);
		end
	elseif (ATSW_ShowWindow) then
		LSW_Mode = "ATSW"
		
		ATSW_ShowWindow_ORIGINAL = ATSW_ShowWindow;
		ATSW_ShowWindow = LSW_ShowWindowATSW;
			
		DEFAULT_CHAT_FRAME:AddMessage("LilSparky's Workshop plugging into AdvancedTradeSkillWindow.");
		
		LSW_TRADESKILL_INDEX_MAX = ATSW_TRADE_SKILLS_DISPLAYED;
		
		LSW_skillWidthNarrow = 223;
		LSW_skillWidthWide = 243;
		
		LSW_skillWidth = LSW_skillWidthNarrow;

		for i=1, LSW_TRADESKILL_INDEX_MAX, 1 do
			LSW_ButtonInitATSW(i);
		end
	else
		DEFAULT_CHAT_FRAME:AddMessage("LilSparky's Workshop plugging into standard Tradeskill/Crafting frames.");

	-- more forced loading, but since i'm pluggin right into the system, i kind of need to
		if (not IsAddOnLoaded("Blizzard_TradeSkillUI")) then
			LoadAddOn("Blizzard_TradeSkillUI");
		end
		
		if (not IsAddOnLoaded("Blizzard_CraftUI")) then
			LoadAddOn("Blizzard_CraftUI");
		end
		
		
		TradeSkillFrame_Show_ORIGINAL = TradeSkillFrame_Show;
		TradeSkillFrame_Show = LSW_ShowWindowStandard;
				
		TradeSkillFrame_Update_ORIGINAL = TradeSkillFrame_Update;
		TradeSkillFrame_Update = LSW_UpdateWindowStandard;
		
		
		CraftFrame_Show_ORIGINAL = CraftFrame_Show;
		CraftFrame_Show = LSW_ShowWindowCraft;
		
		CraftFrame_Update_ORIGINAL = CraftFrame_Update;
		CraftFrame_Update = LSW_UpdateWindowCraft;

		
		LSW_TRADESKILL_INDEX_MAX = TRADE_SKILLS_DISPLAYED;
		LSW_CRAFT_INDEX_MAX = CRAFTS_DISPLAYED;
		
		LSW_skillWidthNarrow = 223;
		LSW_skillWidthWide = 243;
		
		LSW_skillWidth = LSW_skillWidthNarrow;
		
		for i=1, LSW_TRADESKILL_INDEX_MAX, 1 do
			LSW_ButtonInitStandard(i);
		end
	end
	
end

